/*
	Desc:   实时推送引擎客户端
	Author: Tom
	Date:   2020-04-08
*/

var webSocketConnected = false;
var webSocketCallback = null;
var websocket = null;
var websocketDid = '';

var initWebsocket = function(did){
	console.log('init websocket, did = ' + did);
	websocketDid = did;
}

var createWS = function(callback){
	if(callback){
		webSocketCallback = callback;	
	}
    if(webSocketConnected)return;
	var state = app.getState();
	console.log('websocket, state = ' + JSON.stringify(state));
	if(!state)return;
    var username = state.account;
    var password = state.password;
	var url = i18next.language === 'zh' ? 'wss://ws.chease.cn/': 'wss://ws-asia.chease.cn/';
    var wsServer = url + '?account=' + username + '&password=' + password + '&mapType=BAIDU';
	console.log('wsServer:' + wsServer);
    websocket = new WebSocket(wsServer);
    websocket.onopen = function (evt) {
        onOpen(evt)
    };
    websocket.onclose = function (evt) {
        onClose(evt)
    };
    websocket.onmessage = function (evt) {
        onMessage(evt)
    };
    websocket.onerror = function (evt) {
        onError(evt)
    };

    function onOpen(evt) {
        console.log("Connected to WebSocket server.");
        webSocketConnected = true;
    }

    function onClose(evt) {
        console.log("Disconnected");
        webSocketConnected = false;
        createWS();
    }

    function onMessage(evt) {
        console.log('Retrieved data from server: ' + evt.data);
        var content = '';
        var data = JSON.parse(evt.data);
        if(data.msgType === 'OK'){
            content = '连接成功！';
        }else{
            switch (data.type){
                case "location:updated":
                    content = data.did + ' - 位置更新';
                    break;
                case "trip:finished":
                    content = data.did + ' - 行程结束';
                    break;
                case "ignition:on":
                    content = data.did + ' - 点火';
                    break;
                case "ignition:off":
                    content = data.did + ' - 熄火';
                    break;
                case "notification:speeding":
                    content = data.did + ' - 超速报警';
                    break;
                case "notification:alert":
                    content = data.did + ' - 报警 - ' + IOT_ALERT_DESC[data.alertType.toString()];
                    break;
                case "enter:geofence":
                    content = data.did + ' - 进围栏 - ' + data.geofence.name;
                    break;
                case "exit:geofence":
                    content = data.did + ' - 出围栏 - ' + data.geofence.name;
                    break;
                case "notification:vstatus":
					content = data.did + ' - 车辆状态 - ' + JSON.stringify(data.vstatus) + ' - ' + websocketDid;
					if(webSocketCallback && data.did === websocketDid){
						webSocketCallback(data.did, data.vstatus);
					}
                    break;
                default:
                    content = evt.data;
                    break;
            }
        }
        var log = new Date().toLocaleTimeString() + ' - ' + content;
        console.log(log);
    }

    function onError(evt) {
        console.log('Error occured: ' + evt.data);
    }
};

var closeWebSocket = function(){
	if(websocket){
		console.log('close websocket, ' + websocket.id);
		websocket.close();
	}
}

// createWS();